@@ -3,7 +3,8 @@ testthat::context("Order")
 testthat::test_that("Vector ordering", {
   set.seed(1234)
   x <- sample(1:20, size = 20)
-  xOrder <- cpp_orderVector(x)
+  xOrder <- CaseBasedReasoning:::cpp_orderVector(x, sortDirection=0) |>
+    as.numeric()
   yOrder <- order(x)
   testthat::expect_equal(xOrder, yOrder)
 })
@@ -11,7 +12,7 @@ testthat::test_that("Vector ordering", {
 testthat::test_that("Matrix ordering", {
   set.seed((1234))
   x <- matrix(rnorm(100), 10)
-  xOrder <- cpp_orderMatrix(x)
+  xOrder <- CaseBasedReasoning:::cpp_orderMatrix(x, sortDirection = 0, k = 10)
   yOrder <- do.call(cbind, lapply(1:nrow(x), function(col) {order(x[, col])}))
   testthat::expect_equal(xOrder, yOrder)
 })
\ No newline at end of file
